@@ -153,7 +153,7 @@ string_to_uint64 (const char *str, guint64 *value)
 static inline gboolean
 sm_has_header (SoupMessage *msg, const char *header)
 {
-  return soup_message_headers_get (msg->response_headers, header) != NULL;
+  return soup_message_headers_get_one (msg->response_headers, header) != NULL;
 }
 
 static char *
@@ -289,8 +289,8 @@ message_should_apply_redir_ref (SoupMessage *msg)
 {
   const char *header;
 
-  header = soup_message_headers_get (msg->request_headers,
-                                     "Apply-To-Redirect-Ref");
+  header = soup_message_headers_get_one (msg->request_headers,
+                                         "Apply-To-Redirect-Ref");
 
   if (header == NULL || g_ascii_strcasecmp (header, "T"))
     return FALSE;
@@ -350,7 +350,7 @@ redirect_handler (SoupMessage *msg, gpointer user_data)
     gboolean     redirect;
 
     status = msg->status_code;
-    new_loc = soup_message_headers_get (msg->response_headers, "Location");
+    new_loc = soup_message_headers_get_one (msg->response_headers, "Location");
 
     /* If we don't have a location to redirect to, just fail */
     if (new_loc == NULL)
@@ -383,8 +383,8 @@ redirect_handler (SoupMessage *msg, gpointer user_data)
      {
        const char *dest;
 
-       dest = soup_message_headers_get (msg->request_headers,
-                                        "Destination");
+       dest = soup_message_headers_get_one (msg->request_headers,
+                                            "Destination");
 
        if (dest && g_str_has_suffix (dest, "/") == FALSE)
          {
@@ -482,15 +482,12 @@ g_vfs_backend_dav_setup_display_name (GVfsBackend *backend)
     /* Translators: This is the name of the WebDAV share constructed as
        "WebDAV as <username> on <hostname>:<port>"; the ":<port>" part is
        the second %s and only shown if it is not the default http(s) port. */
-    display_name = g_strdup_printf (_("WebDAV as %s on %s%s"),
+    display_name = g_strdup_printf (_("%s on %s%s"),
 				    mount_base->user,
 				    mount_base->host,
 				    port);
   else
-    /* Translators: This is the name of the WebDAV share constructed as
-       "WebDAV on <hostname>:<port>"; The ":port" part is again the second
-       %s and it is only shown if it is not the default http(s) port. */
-    display_name = g_strdup_printf (_("WebDAV on %s%s"),
+    display_name = g_strdup_printf ("%s%s",
 				    mount_base->host,
 				    port);
 
@@ -990,6 +987,7 @@ ms_response_to_file_info (MsResponse *response,
   GFileType   file_type;
   char       *mime_type;
   GIcon      *icon;
+  GIcon      *symbolic_icon;
   gboolean    have_display_name;
 
   basename = ms_response_get_basename (response);
@@ -1067,6 +1065,7 @@ ms_response_to_file_info (MsResponse *response,
   if (file_type == G_FILE_TYPE_DIRECTORY)
     {
       icon = g_themed_icon_new ("folder");
+      symbolic_icon = g_themed_icon_new ("folder-symbolic");
       file_info_set_content_type (info, "inode/directory");
     }
   else
@@ -1075,9 +1074,16 @@ ms_response_to_file_info (MsResponse *response,
         mime_type = g_content_type_guess (basename, NULL, 0, NULL);
 
       icon = g_content_type_get_icon (mime_type);
-
       if (G_IS_THEMED_ICON (icon))
-        g_themed_icon_append_name (G_THEMED_ICON (icon), "text-x-generic");
+        {
+          g_themed_icon_append_name (G_THEMED_ICON (icon), "text-x-generic");
+        }
+
+      symbolic_icon = g_content_type_get_symbolic_icon (mime_type);
+      if (G_IS_THEMED_ICON (icon))
+        {
+          g_themed_icon_append_name (G_THEMED_ICON (symbolic_icon), "text-x-generic-symbolic");
+        }
 
       file_info_set_content_type (info, mime_type);
     }
@@ -1086,7 +1092,9 @@ ms_response_to_file_info (MsResponse *response,
     g_file_info_set_display_name (info, basename);
 
   g_file_info_set_icon (info, icon);
+  g_file_info_set_symbolic_icon (info, symbolic_icon);
   g_object_unref (icon);
+  g_object_unref (symbolic_icon);
   g_free (mime_type);
   g_free (basename);
 
@@ -1937,6 +1945,7 @@ do_mount (GVfsBackend  *backend,
 
   g_vfs_backend_set_mount_spec (backend, mount_spec);
   g_vfs_backend_set_icon_name (backend, "folder-remote");
+  g_vfs_backend_set_symbolic_icon_name (backend, "folder-remote-symbolic");
   
   g_vfs_backend_dav_setup_display_name (backend);
   
@@ -2373,7 +2382,7 @@ try_replace_checked_etag (SoupSession *session, SoupMessage *msg,
   /* TODO: other errors */
 
   open_for_replace_succeeded (op_backend, job, soup_message_get_uri (msg),
-                              soup_message_headers_get (msg->request_headers, "If-Match"));
+                              soup_message_headers_get_one (msg->request_headers, "If-Match"));
 }  
 
 static gboolean
